@@ -1,11 +1,11 @@
-if (interactive()) devtools::load_all()
+if (interactive()) pkgload::load_all()
 
 test_package_path <- function() {
     old <- setwd(tempdir())
     on.exit(setwd(old))
     package_path <- file.path(tempdir(), "anRpackage")
     usethis::create_package(path = package_path)
-    result <- get_pkg_archive_path(package_path)
+    result <- packager::get_pkg_archive_path(package_path)
     expectation <- file.path(tempdir(),
                              "anRpackage", "anRpackage_0.0.0.9000.tar.gz")
     if (identical(.Platform[["OS.type"]], "unix")) {
@@ -24,11 +24,11 @@ test_check_archive <- function() {
     file.copy(system.file("templates", "throw.R", package = "fakemake"),
               file.path(package_path, "R"))
     roxygen2::roxygenize(package_path)
-    tarball <- get_pkg_archive_path(package_path)
+    tarball <- packager::get_pkg_archive_path(package_path)
     devtools::build(pkg = package_path, path = package_path)
-    result <- check_archive(tarball)
+    result <- packager::check_archive(tarball)
     RUnit::checkTrue(result[["status"]] == 0)
-    result <- check_archive_as_cran(tarball)
+    result <- packager::check_archive_as_cran(tarball)
     RUnit::checkTrue(result[["status"]] == 0)
 }
 
